@@ -1,5 +1,3 @@
-from typing import Optional
-
 from pydantic import BaseModel
 
 
@@ -11,7 +9,6 @@ class User(BaseModel):
 
 class Organization(BaseModel):
     id: int  # noqa: A003
-    type: str  # noqa: A003
     login: str
 
 
@@ -20,6 +17,6 @@ class Repository(BaseModel):
     name: str
     full_name: str
     fork: bool
+    url: str
 
     owner: User
-    organization: Optional[Organization]
